summaryrefslogtreecommitdiffstats
path: root/lib/kross/api/interpreter.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /lib/kross/api/interpreter.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kross/api/interpreter.h')
-rw-r--r--lib/kross/api/interpreter.h42
1 files changed, 21 insertions, 21 deletions
diff --git a/lib/kross/api/interpreter.h b/lib/kross/api/interpreter.h
index 5c73c303..443585e3 100644
--- a/lib/kross/api/interpreter.h
+++ b/lib/kross/api/interpreter.h
@@ -20,8 +20,8 @@
#ifndef KROSS_API_INTERPRETER_H
#define KROSS_API_INTERPRETER_H
-#include <qstring.h>
-#include <qmap.h>
+#include <tqstring.h>
+#include <tqmap.h>
#include "object.h"
@@ -53,7 +53,7 @@ namespace Kross { namespace Api {
/**
* Map of options.
*/
- typedef QMap<QString, Option*> Map;
+ typedef TQMap<TQString, Option*> Map;
/**
* Constructor.
@@ -61,25 +61,25 @@ namespace Kross { namespace Api {
* \param name The name the option has. This is the
* displayed title and isn't used internaly.
* \param comment A comment that describes the option.
* \param value The QVariant value this option has.
*/
- Option(const QString& name, const QString& comment, const QVariant& value)
+ Option(const TQString& name, const TQString& comment, const TQVariant& value)
: name(name), comment(comment), value(value) {}
/// The short name of the option.
- QString name;
+ TQString name;
/// A description of the option.
- QString comment;
+ TQString comment;
/// The value the option has.
- QVariant value;
+ TQVariant value;
};
/**
* Constructor.
*/
- InterpreterInfo(const QString& interpretername, const QString& library, const QString& wildcard, QStringList mimetypes, Option::Map options);
+ InterpreterInfo(const TQString& interpretername, const TQString& library, const TQString& wildcard, TQStringList mimetypes, Option::Map options);
/**
* Destructor.
@@ -89,40 +89,40 @@ namespace Kross { namespace Api {
/**
* \return the name of the interpreter. For example "python" or "kjs".
*/
- const QString getInterpretername();
+ const TQString getInterpretername();
/**
* \return the file-wildcard used to determinate by this interpreter
* used scriptingfiles. Those filter will be used e.g. with
- * KGlobal::dirs()->findAllResources() as filtermask. For example
+ * KGlobal::dirs()->findAllResources() as filtertqmask. For example
* python just defines it as "*py".
*/
- const QString getWildcard();
+ const TQString getWildcard();
/**
* List of mimetypes this interpreter supports.
*
* \return QStringList with mimetypes like
* "application/x-javascript".
*/
- const QStringList getMimeTypes();
+ const TQStringList getMimeTypes();
/**
* \return true if an \a Option with that \p key exists else false.
*/
- bool hasOption(const QString& key);
+ bool hasOption(const TQString& key);
/**
* \return the option defined with \p name .
*/
- Option* getOption(const QString name);
+ Option* getOption(const TQString name);
/**
* \return the value of the option defined with \p name . If there
* doesn't exists an option with such a name, the \p defaultvalue
* is returned.
*/
- const QVariant getOptionValue(const QString name, QVariant defaultvalue = QVariant());
+ const TQVariant getOptionValue(const TQString name, TQVariant defaultvalue = TQVariant());
/**
* \return a map of options.
@@ -137,13 +137,13 @@ namespace Kross { namespace Api {
private:
/// The name the interpreter has. Could be something like "python" or "kjs".
- QString m_interpretername;
+ TQString m_interpretername;
/// The name of the library to load for the interpreter.
- QString m_library;
+ TQString m_library;
/// The file wildcard used to determinate extensions.
- QString m_wildcard;
+ TQString m_wildcard;
/// List of mimetypes this interpreter supports.
- QStringList m_mimetypes;
+ TQStringList m_mimetypes;
/// A \a Option::Map with options.
Option::Map m_options;
/// The \a Interpreter instance.
@@ -61,25 +61,25 @@ namespace Kross { namespace Api {
* displayed title and isn't used internaly.
* \param comment A comment that describes the option.
- * \param value The QVariant value this option has.
+ * \param value The TQVariant value this option has.
*/
@@ -89,40 +89,40 @@ namespace Kross { namespace Api {
* List of mimetypes this interpreter supports.
*
- * \return QStringList with mimetypes like
+ * \return TQStringList with mimetypes like
* "application/x-javascript".
*/